@@ -46,32 +46,66 @@ where
     Ok(rope.to_string())
 }
 
-pub fn update_imports(
+pub fn replace_imports<F>(source_file: &PathBuf, source_code: &str, replacer: F) -> Result<String>
+where
+    F: Fn(&String) -> Result<String>,
+{
+    let lang = infer_langauge_from_suffix(&source_file)?;
+    let mut import_finder = ImportFinder::new(&source_code, lang)?;
+    let mut rope = Rope::from_str(&source_code);
+
+    for text_slice in import_finder.find_imports() {
+        let (start_idx, end_idx) = text_slice.to_index_range(&rope);
+
+        let old_import = rope.slice(start_idx..end_idx).to_string();
+
+        if !old_import.starts_with('.') {
+            continue;
+        }
+
+        let new_import = replacer(&old_import)?;
+
+        if old_import.eq(&new_import) {
+            continue;
+        }
+
+        rope.remove(start_idx..end_idx);
+        rope.insert(start_idx, &new_import);
+    }
+    Ok(rope.to_string())
+}
+
+pub fn move_source_file(
     source_code: String,
     source_file: &PathBuf,
     target_file: &PathBuf,
 ) -> Result<String> {
     let lang = infer_langauge_from_suffix(&source_file)?;
-    replace_rel_imports(&source_code, lang, |old_import| {
-        let path = import_string::to_path(&source_file, &old_import)?;
-        import_string::from_paths(&target_file, &path)
+    replace_rel_imports(&source_code, lang, |import_string| {
+        let args = import_string::SourceFileRename {
+            import_string,
+            old_location: source_file,
+            new_location: target_file,
+        };
+        import_string::rename_source_file(&args)
     })
 }
 
-pub fn update_import(
+pub fn move_required_file(
     source_code: &str,
     source_file: &PathBuf,
     old_import_location: &PathBuf,
     new_import_location: &PathBuf,
 ) -> Result<String> {
     let lang = infer_langauge_from_suffix(&source_file)?;
-    replace_rel_imports(&source_code, lang, |old_import| {
-        Ok(
-            match import_string::is_import_from(&source_file, &old_import_location, old_import)? {
-                false => old_import.clone(),
-                true => import_string::from_paths(&source_file, &new_import_location)?,
-            },
-        )
+    replace_rel_imports(&source_code, lang, |import_string| {
+        let args = import_string::RequiredFileRename {
+            source_file,
+            import_string,
+            old_location: old_import_location,
+            new_location: new_import_location,
+        };
+        import_string::rename_required_file(&args)
     })
 }
 
@@ -94,7 +128,7 @@ mod tests {
         let source: PathBuf = "/src/a/b/c/d/source.ts".into();
         let target: PathBuf = "/src/a/b/c/d/e/target.ts".into();
 
-        let new_source_code = super::update_imports(code, &source, &target)?;
+        let new_source_code = super::move_source_file(code, &source, &target)?;
 
         let new_import_0: String = "import some from '../../../some';".into();
         let new_import_1: String = "import other from '../../../other';".into();
@@ -118,7 +152,7 @@ mod tests {
         let source: PathBuf = "/src/a/b/c/d/source.ts".into();
         let target: PathBuf = "/src/a/target.ts".into();
 
-        let new_source_code = super::update_imports(code, &source, &target)?;
+        let new_source_code = super::move_source_file(code, &source, &target)?;
 
         let new_import_0: String = "import some from './b/some';".into();
         let new_import_1: String = "import other from './b/other';".into();
